Struct frame_support::weights::RuntimeDbWeight
pub struct RuntimeDbWeight {
pub read: u64,
pub write: u64,
}Expand description
The weight of database operations that the runtime can invoke.
NOTE: This is currently only measured in computational time, and will probably be updated all together once proof size is accounted for.
Fields
read: u64write: u64Implementations